#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
@author: T. Malfatti <malfatti@disroot.org>
@date: 20170612
@license: GNU GPLv3 <https://gitlab.com/malfatti/SciScripts/raw/master/LICENSE>
@homepage: https://gitlab.com/Malfatti/SciScripts
"""

from sciscripts.IO.OpenEphys import Binary
from sciscripts.IO.OpenEphys import OpenEphysFormat
from sciscripts.IO.OpenEphys import OpenEphys
from sciscripts.IO.OpenEphys import SettingsXML
